@@ -50,11 +50,16 @@ def _cli(target, source, signature_type, host, port, debug, dry_run):
         elif _ctx.runtime == ASYNC:
             signature_type = "of"
             app = create_dapr_app(target, source, signature_type, _ctx)
+        else:
+            raise RuntimeError("this runtime is not allow".format(_ctx.runtime))
     if dry_run:
         click.echo("Function: {}".format(target))
         click.echo("URL: http://{}:{}/".format(host, port))
         click.echo("Dry run successful, shutting down.")
     elif ff != "":
-        create_dapr_server(app, port).run()
+        try:
+            create_dapr_server(app, port).run()
+        except Exception:
+            raise RuntimeError("this is error happen")
     else:
         create_server(app, debug).run(host, port)
